<?php
/**
* Customizer Options
*
* @package CleanWP WordPress Theme
* @copyright Copyright (C) 2024 ThemesDNA
* @license http://www.gnu.org/licenses/gpl-2.0.html GNU/GPLv2 or later
* @author ThemesDNA <themesdna@gmail.com>
*/

function cleanwp_blog_post_style() {
    if ( cleanwp_get_option('blogpoststyle') ) :
        if ( cleanwp_get_option('blogpoststyle') == 'excerpt' ) :
            if ( has_post_thumbnail() ) {
                if ( !(cleanwp_get_option('hide_thumbnail')) ) { ?>
                <?php if ( cleanwp_get_option('thumbnail_link') == 'no' ) { ?>
                    <?php the_post_thumbnail('cleanwp-autoh-image', array('class' => 'entry-featured-image')); ?>
                <?php } else { ?>
                    <a href="<?php echo esc_url( get_permalink() ); ?>"><?php the_post_thumbnail('cleanwp-autoh-image', array('class' => 'entry-featured-image')); ?></a>
                <?php }
                }
            }
            the_excerpt();
        else :
            if ( has_post_thumbnail() ) {
                if ( !(cleanwp_get_option('hide_thumbnail')) ) { ?>
                <?php if ( cleanwp_get_option('thumbnail_link') == 'no' ) { ?>
                    <?php the_post_thumbnail('cleanwp-large-image', array('class' => 'entry-featured-image entry-featured-image-block')); ?>
                <?php } else { ?>
                    <a href="<?php echo esc_url( get_permalink() ); ?>"><?php the_post_thumbnail('cleanwp-large-image', array('class' => 'entry-featured-image entry-featured-image-block')); ?></a>
                <?php }
                }
            }
            the_content( sprintf(
                wp_kses(
                    /* translators: %s: Name of current post. Only visible to screen readers */
                    __( 'Continue reading<span class="cleanwp-sr-only"> "%s"</span> <span class="meta-nav">&rarr;</span>', 'cleanwp' ),
                    array(
                        'span' => array(
                            'class' => array(),
                        ),
                    )
                ),
                wp_kses_post( get_the_title() )
            ) );
        endif;
    else : 
        if ( has_post_thumbnail() ) { 
                if ( !(cleanwp_get_option('hide_thumbnail')) ) { ?>
                <?php if ( cleanwp_get_option('thumbnail_link') == 'no' ) { ?>
                        <?php the_post_thumbnail('cleanwp-autoh-image', array('class' => 'entry-featured-image')); ?>
                <?php } else { ?>
                        <a href="<?php echo esc_url( get_permalink() ); ?>"><?php the_post_thumbnail('cleanwp-autoh-image', array('class' => 'entry-featured-image')); ?></a>
                <?php }
                }
        }
        the_excerpt();
    endif;
}

// Custom CSS
function cleanwp_customcss() {
    if ( cleanwp_get_option('customcss') ) : ?>
      <style type="text/css"><?php echo esc_html( cleanwp_get_option('customcss') ); ?></style>
    <?php endif;
}
add_action('wp_head', 'cleanwp_customcss');

if ( ! function_exists( 'wp_body_open' ) ) :
    /**
     * Fire the wp_body_open action.
     *
     * Added for backwards compatibility to support pre 5.2.0 WordPress versions.
     */
    function wp_body_open() { // phpcs:ignore WPThemeReview.CoreFunctionality.PrefixAllGlobals.NonPrefixedFunctionFound
        /**
         * Triggered after the opening <body> tag.
         */
        do_action( 'wp_body_open' ); // phpcs:ignore WPThemeReview.CoreFunctionality.PrefixAllGlobals.NonPrefixedHooknameFound
    }
endif;

function cleanwp_inline_css() {
    $custom_css = '';

    if ( cleanwp_get_option('header_text_hover_color') ) {
        $custom_css .= '.site-title a:hover,.site-title a:focus,.site-title a:active{color:'.esc_html( cleanwp_get_option('header_text_hover_color') ).';}';
    }

    if ( cleanwp_get_option('body_text_color') ) {
        $custom_css .= 'body,button,input,select,textarea{color:'.esc_html( cleanwp_get_option('body_text_color') ).';}';
    }
    if ( cleanwp_get_option('link_color') ) {
        $custom_css .= 'a{color:'.esc_html( cleanwp_get_option('link_color') ).';}';
    }
    if ( cleanwp_get_option('link_hover_color') ) {
        $custom_css .= 'a:hover{color:'.esc_html( cleanwp_get_option('link_hover_color') ).';}';
    }
    if ( cleanwp_get_option('menu_bg_color') ) {
        $custom_css .= '.main-navigation{background-color:'.esc_html( cleanwp_get_option('menu_bg_color') ).';}';
    }
    if ( cleanwp_get_option('menu_color') ) {
        $custom_css .= '.main-navigation a{color:'.esc_html( cleanwp_get_option('menu_color') ).';}';
        $custom_css .= '@media screen and (max-width: 1049px) {.menu-toggle,.main-navigation{color:'.esc_html( cleanwp_get_option('menu_color') ).';}}';
    }
    if ( cleanwp_get_option('menu_hover_color') ) {
        $custom_css .= '.main-navigation a:hover,.main-navigation a:focus,.main-navigation a:active,.main-navigation ul:hover > a,.main-navigation ul:focus > a,.main-navigation ul:active > a,.main-navigation ul ul:hover > a,.main-navigation ul ul:focus > a,.main-navigation ul ul:active > a{color:'.esc_html( cleanwp_get_option('menu_hover_color') ).';}';
        $custom_css .= '.main-navigation ul li.focus > a{color:'.esc_html( cleanwp_get_option('menu_hover_color') ).';}';
    }
    if ( cleanwp_get_option('menu_current_color') ) {
        $custom_css .= '.main-navigation li.current_page_item > a,.main-navigation li.current-menu-item > a,.main-navigation li.current_page_ancestor > a,.main-navigation li.current-menu-ancestor > a{color:'.esc_html( cleanwp_get_option('menu_current_color') ).';}';
    }
    if ( cleanwp_get_option('submenu_one_bg_color') ) {
        $custom_css .= '.main-navigation ul ul{background-color:'.esc_html( cleanwp_get_option('submenu_one_bg_color') ).';}';
        $custom_css .= '@media screen and (max-width: 1049px) {.main-navigation ul ul{background-color: transparent;}}';
    }
    if ( cleanwp_get_option('submenu_two_bg_color') ) {
        $custom_css .= '.main-navigation ul ul ul{background-color:'.esc_html( cleanwp_get_option('submenu_two_bg_color') ).';}';
        $custom_css .= '@media screen and (max-width: 1049px) {.main-navigation ul ul ul{background-color: transparent;}}';
    }

    if ( cleanwp_get_option('post_headings_color') ) {
        $custom_css .= '.entry-title,.entry-title a{color:'.esc_html( cleanwp_get_option('post_headings_color') ).';}';
    }
    if ( cleanwp_get_option('post_headings_hover_color') ) {
        $custom_css .= '.entry-title a:hover,.entry-title a:focus,.entry-title a:active{color:'.esc_html( cleanwp_get_option('post_headings_hover_color') ).';}';
    }

    if ( cleanwp_get_option('sidebar_headings_color') ) {
        $custom_css .= '.widget-title,.widget-title a,.widget-title a:hover,.widget-title a:focus,.widget-title a:active{color:'.esc_html( cleanwp_get_option('sidebar_headings_color') ).';}';
    }
    if ( cleanwp_get_option('sidebar_text_color') ) {
        $custom_css .= '.side-widget{color:'.esc_html( cleanwp_get_option('sidebar_text_color') ).';}';
    }
    if ( cleanwp_get_option('sidebar_link_color') ) {
        $custom_css .= '.side-widget a{color:'.esc_html( cleanwp_get_option('sidebar_link_color') ).';}';
    }
    if ( cleanwp_get_option('sidebar_link_hover_color') ) {
        $custom_css .= '.side-widget a:hover,.side-widget a:focus,.side-widget a:active{color:'.esc_html( cleanwp_get_option('sidebar_link_hover_color') ).';}';
    }

    if ( cleanwp_get_option('footer_headings_color') ) {
        $custom_css .= '.fwidget-title,.fwidget-title a,.fwidget-title a:hover,.fwidget-title a:focus,.fwidget-title a:active{color:'.esc_html( cleanwp_get_option('footer_headings_color') ).';}';
    }
    if ( cleanwp_get_option('footer_text_color') ) {
        $custom_css .= '.footer-widget{color:'.esc_html( cleanwp_get_option('footer_text_color') ).';}';
    }
    if ( cleanwp_get_option('footer_link_color') ) {
        $custom_css .= '.footer-widget a{color:'.esc_html( cleanwp_get_option('footer_link_color') ).';}';
    }
    if ( cleanwp_get_option('footer_link_hover_color') ) {
        $custom_css .= '.footer-widget a:hover,.footer-widget a:focus,.footer-widget a:active{color:'.esc_html( cleanwp_get_option('footer_link_hover_color') ).';}';
    }

    if ( cleanwp_get_option('main_border_color') ) {
        $custom_css .= '#content,.hentry,.entry-title,.postbox,.entry-meta,footer.entry-footer,.side-widget,.widget-title,.side-widget ul li,.side-widget ul li li,h2.comments-title{border-color:'.esc_html( cleanwp_get_option('main_border_color') ).';}';
    }

    if ( cleanwp_get_option('hide_posted_date') ) {
        $custom_css .= '.posted-on{display:none;}';
    }
    if ( cleanwp_get_option('hide_post_author') ) {
        $custom_css .= '.byline{display:none;}';
        $custom_css .= '.single .byline,.group-blog .byline{display:none;}';
    }
    if ( cleanwp_get_option('hide_post_categories') ) {
        $custom_css .= '.cat-links{display:none;}';
    }
    if ( cleanwp_get_option('hide_post_tags') ) {
        $custom_css .= '.tags-links{display:none;}';
    }
    if ( cleanwp_get_option('hide_comments_link') ) {
        $custom_css .= '.comments-link{display:none;}';
    }
    if ( cleanwp_get_option('hide_read_more_button') ) {
        $custom_css .= '.entry-read-more{display:none;}';
    }

    if( '' != $custom_css ) {
        wp_add_inline_style( 'cleanwp-maincss', $custom_css );
    }
}
add_action( 'wp_enqueue_scripts', 'cleanwp_inline_css' );

// Header styles
if ( ! function_exists( 'cleanwp_header_style' ) ) :
function cleanwp_header_style() {
    $header_text_color = get_header_textcolor();
    if ( get_theme_support( 'custom-header', 'default-text-color' ) === $header_text_color ) { return; }
    ?>
    <style type="text/css">
    <?php if ( ! display_header_text() ) : ?>
        .site-title, .site-description {position: absolute;clip: rect(1px, 1px, 1px, 1px);}
    <?php else : ?>
        .site-title, .site-title a, .site-description {color: #<?php echo esc_attr( $header_text_color ); ?>;}
    <?php endif; ?>
    </style>
    <?php
}
endif;