<?php
/**
* Post meta, navigations, site titles functions
*
* @package CleanWP WordPress Theme
* @copyright Copyright (C) 2024 ThemesDNA
* @license http://www.gnu.org/licenses/gpl-2.0.html GNU/GPLv2 or later
* @author ThemesDNA <themesdna@gmail.com>
*/

if ( ! function_exists( 'cleanwp_posted_on' ) ) :
/**
 * Prints HTML with meta information for the current post-date/time and author.
 */
function cleanwp_posted_on() {
    $time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
    if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
        $time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
    }

    $time_string = sprintf( $time_string,
        esc_attr( get_the_date( 'c' ) ),
        esc_html( get_the_date() ),
        esc_attr( get_the_modified_date( 'c' ) ),
        esc_html( get_the_modified_date() )
    );

    $posted_on = sprintf(
        /* translators: %s: post date. */ _x( '<i class="fas fa-calendar" aria-hidden="true"></i> Posted on %s', 'post date', 'cleanwp' ),
        '<a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . $time_string . '</a>&nbsp;&nbsp;'
    );

    $byline = sprintf(
        /* translators: %s: post author. */ _x( '<i class="fas fa-user" aria-hidden="true"></i> by %s', 'post author', 'cleanwp' ),
        '<span class="author vcard" itemscope="itemscope" itemtype="http://schema.org/Person" itemprop="author"><a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . esc_html( get_the_author() ) . '</a></span>'
    );

    echo '<span class="posted-on">' . $posted_on . '</span><span class="byline"> ' . $byline . '</span>'; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
}
endif;

if ( ! function_exists( 'cleanwp_entry_footer' ) ) :
/**
 * Prints HTML with meta information for the categories, tags and comments.
 */
function cleanwp_entry_footer() {
    if ( 'post' == get_post_type() ) {
        /* translators: used between list items, there is a space after the comma */
        $categories_list = get_the_category_list( esc_html__( ', ', 'cleanwp' ) );
        if ( $categories_list ) {
            /* translators: 1: list of categories. */ printf( '<span class="cat-links"><i class="fas fa-folder-open" aria-hidden="true"></i> ' . esc_html__( 'Posted in %1$s', 'cleanwp' ) . '&nbsp;&nbsp;&nbsp;</span>', $categories_list ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
        }
        /* translators: used between list items, there is a space after the comma */
        $tags_list = get_the_tag_list( '', esc_html_x( ', ', 'list item separator', 'cleanwp' ) );
        if ( $tags_list ) {
            /* translators: 1: list of tags. */ printf( '<span class="tags-links"><i class="fas fa-tags" aria-hidden="true"></i> ' . esc_html__( 'Tagged %1$s', 'cleanwp' ) . '&nbsp;&nbsp;&nbsp;</span>', $tags_list ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
        }
    }
    if ( ! post_password_required() && ( comments_open() || get_comments_number() ) ) {
        echo '<span class="comments-link"><i class="fas fa-comments" aria-hidden="true"></i> ';
        comments_popup_link( sprintf( wp_kses( /* translators: %s: post title */ __( 'Leave a Comment<span class="cleanwp-sr-only"> on %s</span>', 'cleanwp' ), array( 'span' => array( 'class' => array(), ), ) ), wp_kses_post( get_the_title() ) ) );
        echo '&nbsp;&nbsp;&nbsp;</span>';
    }
    edit_post_link( sprintf( wp_kses( /* translators: %s: Name of current post. Only visible to screen readers */ __( 'Edit<span class="cleanwp-sr-only"> %s</span>', 'cleanwp' ), array( 'span' => array( 'class' => array(), ), ) ), wp_kses_post( get_the_title() ) ), '<span class="edit-link"><i class="fas fa-pencil-alt" aria-hidden="true"></i> ', '</span>' );
}
endif;

if ( ! function_exists( 'cleanwp_wp_pagenavi' ) ) :
function cleanwp_wp_pagenavi() {
    ?>
    <nav class="navigation posts-navigation cleanwp-clearfix" role="navigation">
        <?php wp_pagenavi(); ?>
    </nav><!-- .navigation -->
    <?php
}
endif;

if ( ! function_exists( 'cleanwp_posts_navigation' ) ) :
function cleanwp_posts_navigation() {
    if ( !(cleanwp_get_option('hide_posts_navigation')) ) {
        if ( function_exists( 'wp_pagenavi' ) ) {
            cleanwp_wp_pagenavi();
        } else {
            if ( cleanwp_get_option('posts_navigation_type') === 'numberednavi' ) {
                the_posts_pagination(array('mid_size' => 2, 'prev_text' => esc_html__( '&larr; Newer posts', 'cleanwp' ), 'next_text' => esc_html__( 'Older posts &rarr;', 'cleanwp' )));
            } else {
                the_posts_navigation(array('prev_text' => esc_html__( 'Older posts &rarr;', 'cleanwp' ), 'next_text' => esc_html__( '&larr; Newer posts', 'cleanwp' )));
            }
        }
    }
}
endif;

if ( ! function_exists( 'cleanwp_post_navigation' ) ) :
function cleanwp_post_navigation() {
    global $post;
    if ( !(cleanwp_get_option('hide_post_navigation')) ) {
            the_post_navigation(array('prev_text' => esc_html__( '%title &rarr;', 'cleanwp' ), 'next_text' => esc_html__( '&larr; %title', 'cleanwp' )));
    }
}
endif;